This bank statement reader can be used to read nigerian bank statement in pdf format.

It helps to extract the following details

Update Dependencies
pip freeze > requirements.txt

Run Test

poetry run pytest -v 

build for publishing 
poetry build

publish to pytest

poetry publish 

Build and Publish 

poetry publish --build

Run Test on Bank Statement
python main.py